@@ -5,28 +5,37 @@ __all__ = []
 import logging
 
 from .utils import JmmcAPI
+from . import PRODLABEL
 
 logger = logging.getLogger(__name__)
 
-
-PRODLABEL = {True: "production", False: "pre-prod"}
-
-
 class Catalog():
     """ Get remote access to read and update catalogs exposed through JMMC's API.
-    Credential can be explicitly given but .netrc file will be automagically used on 401.
+    Credential can be explicitly g"TODO-SCIENCE": [
+            "Check DIT table from the last template user manuals",
+            "Use a calibrator template for MATISSE (instead of default hyb_obs)",
+            "flag ~important~ keywords which MUST be set in a2p2 code and not leaved to there default values"
+        ],
+        "TODO-DEV": [
+            "Support multiple period version (two major at least)",
+            "Add warning if Aspro2's IP versions differs from the selected container",
+            "Support numlist keyword : eg. SEQ.HWPOFF (done in conf but must be range check compatible)",
+            "Optimize VLTI run chooser : DEMO tests suffer from a long run filtering",
+            "Unify ob name creation in vlti instrument createOB()",
+            "Complete test suite with real p2 submission",
+            "Try to read OB in P2 and send them back to Aspro2 as a new obs",
+        ],iven but .netrc file will be automagically used on 401.
     """
 
-    # TODO move preprod toggle False by default
-    def __init__(self, catalogName, username=None, password=None, preprod=True, apiUrl=None):
+    def __init__(self, catalogName, username=None, password=None, prod=False, apiUrl=None):
         self.catalogName = catalogName
-        self.prod = not(preprod)
-        # TODO manage here prod & preprod access points
+        self.prod = prod
 
+        # Manage prod & preprod or user provided access points
         if apiUrl:
             self.apiUrl = apiUrl  # trust given url as catalogAPI if value is provided
         elif self.prod:
-            self.apiUrl = ""  # no api in production yet
+            self.apiUrl = "https://oidb.jmmc.fr/restxq/catalogs"
         else:
             self.apiUrl = "https://oidb-beta.jmmc.fr/restxq/catalogs"
 
@@ -73,4 +82,4 @@ class Catalog():
             Values is an array of row to add. id column values will be ignored.
             usage: addCatalogRows([ { "id":42, "col_a":"a" }, { "id":24, "col_b":"b" } ])
         """
-        return self.api._post("/%s" % (self.catalogName), values)
+        return self.api._post("/%s" % (self.catalogName), json=values)
